Creates a checkbox group tutorial quiz question. The student may select one or more checkboxes before submitting their answer.
question_checkbox(
text,
...,
correct = "Correct!",
incorrect = "Incorrect",
try_again = incorrect,
allow_retry = FALSE,
random_answer_order = FALSE
)Question or option text
answers and extra parameters passed onto question.
For question, text to print for a correct answer (defaults
to "Correct!"). For answer, a boolean indicating whether this answer is
correct.
Text to print for an incorrect answer (defaults to "Incorrect")
when allow_retry is FALSE.
Text to print for an incorrect answer (defaults to "Incorrect")
when allow_retry is TRUE.
Allow retry for incorrect answers. Defaults to FALSE.
Display answers in a random order.
question_checkbox(
"Select all the toppings that belong on a Margherita Pizza:",
answer("tomato", correct = TRUE),
answer("mozzarella", correct = TRUE),
answer("basil", correct = TRUE),
answer("extra virgin olive oil", correct = TRUE),
answer("pepperoni", message = "Great topping! ... just not on a Margherita Pizza"),
answer("onions"),
answer("bacon"),
answer("spinach"),
random_answer_order = TRUE,
allow_retry = TRUE,
try_again = "Be sure to select all four toppings!"
)
#> Question: "Select all the toppings that belong on a Margherita Pizza:"
#> type: "learnr_checkbox"
#> allow_retry: TRUE
#> random_answer_order: TRUE
#> answers:
#> ✔: "tomato"
#> ✔: "mozzarella"
#> ✔: "basil"
#> ✔: "extra virgin olive oil"
#> X: "pepperoni"; "Great topping! ... just not on a Margherita Pizza"
#> X: "onions"
#> X: "bacon"
#> X: "spinach"
#> messages:
#> correct: "Correct!"
#> incorrect: "Incorrect"
#> try_again: "Incorrect"