Creates a text box group tutorial quiz question.
question_text(
text,
...,
correct = "Correct!",
incorrect = "Incorrect",
try_again = incorrect,
allow_retry = FALSE,
random_answer_order = FALSE,
placeholder = "Enter answer here...",
trim = TRUE,
options = list()
)Question or option text
answers and extra parameters passed onto question.
For question, text to print for a correct answer (defaults
to "Correct!"). For answer, a boolean indicating whether this answer is
correct.
Text to print for an incorrect answer (defaults to "Incorrect")
when allow_retry is FALSE.
Text to print for an incorrect answer (defaults to "Incorrect")
when allow_retry is TRUE.
Allow retry for incorrect answers. Defaults to FALSE.
Display answers in a random order.
A character string giving the user a hint as to what can be entered into the control. Internet Explorer 8 and 9 do not support this option.
Logical to determine if whitespace before and after the answer should be removed. Defaults to TRUE.
Extra options to be stored in the question object.
question_text(
"Please enter the word 'C0rrect' below:",
answer("correct", message = "Don't forget to capitalize"),
answer("c0rrect", message = "Don't forget to capitalize"),
answer("Correct", message = "Is it really an 'o'?"),
answer("C0rrect ", message = "Make sure you do not have a trailing space"),
answer("C0rrect", correct = TRUE),
allow_retry = TRUE,
trim = FALSE
)
#> Question: "Please enter the word 'C0rrect' below:"
#> type: "learnr_text"
#> allow_retry: TRUE
#> random_answer_order: FALSE
#> answers:
#> X: "correct"; "Don't forget to capitalize"
#> X: "c0rrect"; "Don't forget to capitalize"
#> X: "Correct"; "Is it really an 'o'?"
#> X: "C0rrect "; "Make sure you do not have a trailing space"
#> ✔: "C0rrect"
#> messages:
#> correct: "Correct!"
#> incorrect: "Incorrect"
#> try_again: "Incorrect"
#> Options:
#> placeholder: "Enter answer here..."
#> trim: FALSE