R/tutorial_package_dependencies.R
tutorial_package_dependencies.RdList the R packages required to run a particular tutorial.
tutorial_package_dependencies(name = NULL, package = NULL)The tutorial name. If name is NULL, then all
tutorials within package will be searched.
The R package providing the tutorial. If package is
NULL, then all tutorials will be searched.
A character vector of package names that are required for execution.
tutorial_package_dependencies(package = "learnr")
#> [1] "Lahman" "dygraphs" "knitr" "learnr" "nycflights13"
#> [6] "rmarkdown" "shiny" "sortable" "tidyverse"